function plot_map(hTsgGUI, hPlotAxes)
% Function to plot the earth map and ship trackline
%
% Input
% -----
% hTsgGUI ............ Handel to the main user interface
% hPlotAxes .......... Handels to the graphic axes
%
% Output
% ------
%
% Library : 'M_MAP'
%
% TODOS
%
% note that a decimal degree notation is used, so that a longitude of 
% 12030'W is specified as -120.5
%
% PROBLEM NOT YET RESOLVED
%    Does M_MAP use 0-360 or -180 +180 covention ?
%
% $Id$

% Retrieve named application data
% -------------------------------
tsg = getappdata( hTsgGUI, 'tsg_data');

% Get the Geographic limit of the TSG time series
% -----------------------------------------------
dateLim = get(hPlotAxes(1), 'Xlim');
ind = find( tsg.DAYD >= dateLim(1) & tsg.DAYD <= dateLim(2));

if ~isempty( ind )

  latMin = min( tsg.LATX(ind) );
  if latMin < -90
    latMin = -90;
  end
  latMax = max( tsg.LATX(ind) );
  if latMax > 90
    latMax = 90;
  end
  lonMin = min( tsg.LONX(ind) );
  lonMax = max( tsg.LONX(ind) );

  % Oversize window due to the large frame
  %--------------------------------------
  latRange = (latMax-latMin);
  latMin = max(min(latMin - 0.05*latRange, latMin - 2), -90);
  latMax = min(max(latMax + 0.05*latRange, latMax + 2), 90);

  lonRange = (lonMax-lonMin);
  lonMin = min(lonMin - 0.03*lonRange, lonMin -2);
  lonMax = max(lonMax + 0.03*lonRange, lonMax +2);

  lonRange = (lonMax-lonMin);
  if lonRange>=360
    lonMin = -183.6;     %to account for fancy frame
    lonMax = 183.6;
    tsg.lonplus = 180;
    tsg.lonmod = 360;
  else
    tsg.lonplus = 0;
    tsg.lonmod = 0;
  end

  % Positionning the right axes (set map current axe)
  % -------------------------------------------------
  axes(hPlotAxes(4));

  % Use of Mercator projection
  % --------------------------
  m_proj('Mercator','lat',[latMin latMax],'long',[lonMin lonMax]);

  switch tsg.preference.map_resolution

    case 1
      % Low-resolution coast lines
      % --------------------------
      m_coast('patch',[.7 .7 .7], 'TAG', 'TAG_PLOT4_LINE_COAST');

    case 2
      % Medium-resolution coast lines
      % -----------------------------
      m_gshhs_l('patch',[.7 .7 .7], 'TAG', 'TAG_PLOT4_LINE_COAST');

    case 3
      % High-resolution coast lines
      % ----------------------------
      m_gshhs_i('patch',[.7 .7 .7], 'TAG', 'TAG_PLOT4_LINE_COAST');

    otherwise
      tsg.preference.map_resolution = 1;
      % Low-resolution coast lines
      % --------------------------
      m_coast('patch',[.7 .7 .7], 'TAG', 'TAG_PLOT4_LINE_COAST');

  end

  % Make a grid on the map with fancy box
  % -------------------------------------
  m_grid('box', 'fancy', 'tickdir', 'in', 'TAG', 'TAG_PLOT4_LINE_GRID', 'Fontsize', 10);

  % Plot the ship track - Check if LAT-LON in deg-decimal
  % -----------------------------------------------------
  %m_line(tsg.LONX,tsg.LATX, 'TAG', 'TAG_PLOT4_LINE_SHIPTRACK', 'marker','.','markersize',3,'color','b');
  %   m_line(tsg.LONX,tsg.LATX, 'LineStyle', 'none', 'marker','*','markersize',2,'color','b');

  % Plot using QC
  % -------------

  % Get list of keys from hashtable tsg.qc.hash, defined inside
  % tsg_initialisation.m
  % -----------------------------------------------------------
  qc_list = keys(tsg.qc.hash);

  % Plot Sample/TSG differences on axe 2
  % iterate (loop) on each key store inside hastable
  % ------------------------------------------------
  for key = qc_list

    % get  some values in hashtable
    % -----------------------------
    %qcState = tsg.qc.hash.(key).state;
    qcCode  = tsg.qc.hash.(key).code;
    qcColor = tsg.qc.hash.(key).color;

    % plot tsg salinity sample with right code/color
    % ----------------------------------------------
    ind = find( tsg.SSPS_QC == qcCode & isnan(tsg.SSPS) == 0);
    if ~isempty( ind )
      
      % Create line on the map
      % ----------------------
      m_line( mod(tsg.LONX(ind) + tsg.lonplus, tsg.lonmod) - tsg.lonplus,...
              tsg.LATX(ind), 'LineStyle', 'none', 'marker','*',...
              'markersize', 2, 'color', qcColor);
    end
  end

  % Write title
  % -----------
  title( ['Cruise: ' tsg.file.name], 'fontsize', 14, 'fontweight', 'bold');

  % Set tag for each line
  % ---------------------
  hLines = get(hPlotAxes(4), 'Children');
  for i=1:length(hLines)
    set(hLines(i), 'Tag', ['TAG_PLOT4_LINE_MAP' int2str(i)]);
  end

  % Save tsg structure
  % ------------------
  setappdata( hTsgGUI, 'tsg_data', tsg);

end

